@@ -166,7 +166,7 @@ setMethod(
 				   alternative = c("two.sided", "less", "greater"), 
 				   conf.level = 0.95, success=NULL, ..., data = parent.frame(), data.name) 
 		  {
-			  formula <- mosaic_formula(x, groups=NULL, max.slots=1)
+			  formula <- mosaic_formula_q(x, groups=NULL, max.slots=1)
 			  missing.n <- missing(n)
 			  missing.data <- missing(data)
 			  dots <- list(...)
