@@ -1,3 +1,5 @@
+utils::globalVariables(c(".group", ".color", ".cond", "mypanel"))
+
 #' Plot a regression model
 #' 
 #' @description Visualize a regression model amid the data that generated it. 
@@ -5,6 +7,10 @@
 #' @param mod A model of type \code{\link{lm}} or \code{\link{glm}}
 #' @param \dots arguments passed to \code{\link{xyplot}} or \code{rgl::plot3d}.
 #'
+#' @section Caution:
+#' This is still underdevelopment.  The API is subject to change, and some
+#' use cases may not work yet.  Watch for improvments in subsequent versions of the package.
+#' 
 #' @details The goal of this function is to assist with visualization
 #' of statistical models. Namely, to plot the model on top of the data
 #' from which the model was fit. 
@@ -55,7 +61,7 @@
 #' # multiple categorical vars
 #' mod <- lm( mpg ~ wt + factor(cyl) + factor(vs) + factor(am), data = mtcars)
 #' plotModel(mod)
-#' plotModel(mod, key = ~am)
+#' plotModel(mod, mpg ~ am)
 #' 
 #' # interaction
 #' mod <- lm( mpg ~ wt + factor(cyl) + wt:factor(cyl), data = mtcars)
@@ -82,9 +88,9 @@
 #' plotModel(mod)
 #' 
 #' # interaction planes
-#' # not work -- need better logic in function
 #' mod <- lm( mpg ~ wt + hp + wt * factor(cyl), data = mtcars)
 #' plotModel(mod)
+#' plotModel(mod, system="g") + facet_wrap( ~ cyl )
 #' 
 
 # ------------------------------------------------------------------------------
@@ -104,100 +110,179 @@ plotModel.default <- function(mod, ...) {
 }
 
 plotModel.parsedModel <- 
-  function(x, key=1, ..., auto.key = NULL, drop = TRUE, max.levels = 9L, system=c("lattice", "ggplot2")) {
+  function(x, formula = NULL, ..., auto.key = NULL, drop = TRUE, 
+           max.levels = 9L, system=c("lattice", "ggplot2")) {
     
     system <- match.arg(system)
-    
-    if (inherits(key, "formula")) {
-      key <- all.vars(rhs(key))
-    }
-    
-    if (length(key) > 1L) 
-      stop("Only one key variable allowed (so far).")
-    
+  
     if (length(x$varTypes) < 2L) 
-      stop("Only models with explanatory variables can be plotted (so far).")
+      stop("Only models with explanatory variables can be plotted.")
     
-    key <- x$varTypes[-1][key]
-    formula <- y ~ x
-    formula[[2]] <- as.name(x$responseName)
-    formula[[3]] <- as.name(names(key))
-    other_data <- x$data[, -1, drop=FALSE]
-    other_data[[names(key)]] <- NULL
-    
-    categories_all <- expand.grid(lapply(other_data, unique))
-    categories_shown <- categories_all
-    if (nrow(categories_all) > max.levels) { 
-      warning("Randomly sampling some of the ", 
-              nrow(categories_all), 
-              " levels of the fit function for you.",
-              call. = FALSE) 
-      categories_shown <- categories_all %>% sample_n(max.levels)
+    if (! inherits(formula, "formula")) { 
+      key <- x$varTypes[-1][1]
+      formula <- y ~ x
+      formula[[2]] <- as.name(x$responseName)
+      formula[[3]] <- as.name(names(key))
     }
+   
+    # variable groups
+    #  * keyVar = x-axis variable
+    #  * coVars = other rhs vars
+    #  * condVars = variables in condition
+    #  * restVars: other variables in the model
+    
+    key <- all.vars(rhs(formula))[1]
+    coVars <- intersect( setdiff(all.vars(rhs(formula)), key), names(x$varTypes) )
+    condVars <- intersect( all.vars(condition(formula)), names(x$varTypes) )
+    other_data <- x$data[, -1, drop=FALSE]
+    other_data[[key]] <- NULL
+    restVars <- setdiff( names(other_data), union(coVars, condVars) )
+    discreteVars <- names(x$varTypes[x$varTypes == "discrete"])
+    
+    nonEmpty <- function(data, varTypes = x$varTypes) {
+        if (ncol(data) == 0L) data$blank <- ""
+        data
+      }
+    
+    discretePart <- function(data, varTypes = x$varTypes) {
+      data[ , intersect(names(data), names(varTypes[varTypes == "discrete"])), drop=FALSE]
+    }
+    
+    my_interaction <- function( data, drop = TRUE, sep = ":", lex.order = TRUE ) {
+      if (ncol(data) == 0L) {
+        factor(rep("", nrow(data)))
+      } else {
+        interaction( data, drop = drop, sep = sep, lex.order = TRUE )
+      }
+    }
+      
+
+# Some aux variables:
+#   .color: one for each combination of discrete co-vars
+#       this determines the color of the lines
+#   .group: one for each combination of co-vars (selected levels of contintuous too)
+#       this determins which points are connected to make curves
+#   .cond:  one for each combination of discrete cond-vars
+#       this determines which lines show up in which panels
+    
+    point_data <- 
+      x$data %>%
+      mutate(
+        .color = my_interaction(x$data[, intersect(discreteVars, restVars), 
+                                       drop = FALSE]),
+        .group = my_interaction(x$data[, c(coVars, restVars), drop = FALSE]),
+        .cond = my_interaction(x$data[, condVars, drop = FALSE])
+      )
+   
+    
+# create data for lines
+    # utility function 
+    some_levels <- function(x) {
+      if (is.numeric(x)) 
+        return( sort(unique(ntiles(x, 3, format = "median"))) )
+      return(sort(unique(x)))
+    }
+   
+    # a few values of each explanatory variable
+    
+    levels_all <- expand.grid(lapply(other_data, some_levels))
+    levels_shown <- levels_all
     
     # convert the model into a function
     modelFunc <- makeFun(x$model)
+   
+    # eplanatory variable
     
-    if (key == "continuous") {
-      p <- xyplot(
-        formula, 
-        data = x$data
-      )
+    if (x$varTypes[key] == "continuous") {
+      p <- xyplot( formula,  data = x$data )
       x_points <- seq(p$x.limits[1], p$x.limits[2], length.out = 40)
     } else {
-      x_points <- unique( x$data[[names(key)]] )
+      x_points <- unique( x$data[[key]] )
     }
     
-    if( nrow(categories_shown) > 0L) {
-      if (is.null(auto.key)) auto.key <- list(points = TRUE, lines=TRUE, columns = 3)
-      # categories[["id"]] <- factor(1:nrow(categories))
-      categories_all <- categories_all %>% mutate(id = interaction(categories_all, drop = drop))
-      categories_shown <- categories_shown %>% mutate(id = interaction(categories_shown, drop = drop))
-      other_data <- suppressMessages(other_data %>% left_join(categories_all))
-      point_data <- suppressMessages(x$data %>% left_join(categories_all))
-      line_data <- bind_rows(lapply(1:length(x_points), function(x) categories_shown)) 
-      line_data[["x"]] <-
-        line_data[[names(key)]] <- 
-          rep(x_points, times = nrow(categories_shown))
-    } else {
+    if (length(restVars) > 0L && is.null(auto.key)) {
+      auto.key <- 
+        list(points = TRUE, lines=TRUE, 
+             columns = min(length(unique(point_data$.color)), 3))
+    } else { 
       if (is.null(auto.key)) auto.key <- FALSE
-      point_data <- x$data 
-      point_data[["id"]] <- factor(" ")
-      line_data <- data.frame(x = x_points, id=factor(" ")) 
-      line_data[[names(key)]] <- x_points
     }
     
+    if (nrow(levels_shown) == 0L) {
+      levels_shown <- data.frame( matrix(nrow = length(x_points), ncol=0) )
+    }
+      
+    line_data <- bind_rows(lapply(1:length(x_points), function(x) levels_shown)) 
+    
+    line_data[["x"]] <-
+      line_data[[key]] <- 
+      rep(x_points, times = nrow(levels_shown))
+    
     line_data[["y"]] <- 
       line_data[[x$responseName]] <- 
       predict(x$model, newdata=line_data, type="response")
     
+    line_data <- 
+      line_data %>%
+      mutate(
+        .color = my_interaction(line_data[, restVars, drop = FALSE]),
+        .group = my_interaction(line_data[, c(coVars, restVars, condVars), drop = FALSE]),
+        .cond = my_interaction(line_data[, condVars, drop = FALSE])
+      )
+    
+    
     mypanel <- 
-      function(x, y, line_data, ...) {
+      function(x, y, line_data, point_data, 
+               group.number = NULL, group.value = NULL, type = "p",
+               ...) {
         panel.xyplot(x, y, type = "p", ...)
-        line_data <- line_data %>% arrange(id, x)
+        line_data <- 
+          line_data %>% 
+          arrange(.color, .group, x) 
+        if (! is.null(group.value) ) {
+          line_data <- line_data %>% filter(as.numeric(.cond) == packet.number())
+        }
+        ncolors <- length(unique(line_data$.color))
+        ngroups <- length(unique(line_data$.group))
         grid::grid.polyline(
           x = line_data$x, 
           y = line_data$y, 
           default.units = "native",
-          id = as.numeric(line_data$id),
-          gp = gpar(col = trellis.par.get("superpose.line")$col)
+          id = as.numeric(line_data$.group),
+          gp = gpar(
+            col = trellis.par.get("superpose.line")$col[1:base::max(as.numeric(line_data$.color))]
+          )
         )
       }
-    
     if (system == "ggplot2") {
       ggplot() +
-        geom_point(aes_string(y = x$responseName, x = names(key), colour="id"), size=1.2,
+        geom_point(aes_string(y = x$responseName, x = key, colour=".color", group=".group"), size=1.2,
                    data = point_data %>% droplevels()) +
-        geom_line (aes_string(y = x$responseName, x = names(key), colour="id"), size=0.5,
+        geom_line (aes_string(y = x$responseName, x = key, colour=".color", group = ".group"), size=0.5,
                    data = line_data %>% droplevels())
     } else {
       xyplot(formula, 
              data = point_data %>% droplevels(),
              line_data = line_data %>% droplevels(),
-             groups = id,
+             point_data = point_data %>% droplevels(),
+             groups = .color,
              auto.key = auto.key,
              ...,
-             panel = mypanel) 
+             panel = panel.superpose,
+             panel.groups = mypanel) 
+#       xyplot( formula, data = point_data,
+#               groups = .group,
+#               auto.key = TRUE,
+#               ...) +
+#         latticeExtra::as.layer(
+#           xyplot(formula, data = line_data,
+#                  type = 'l',
+#                  groups = .group,
+#                  auto.key = TRUE,
+#                  ...
+#           ))
+#                  
+      
     } 
   }
 
